@@ -6,6 +6,7 @@ SMILES
 
 from __future__ import annotations
 
+from ..molecules import Molecule
 from .molecule import MoleculeKeyMaker
 from .utilities import get_smiles
 
@@ -45,7 +46,13 @@ class Smiles(MoleculeKeyMaker):
 
         """
 
-        super().__init__('SMILES', get_smiles)
+        pass
+
+    def get_key_name(self) -> str:
+        return 'SMILES'
+
+    def get_key(self, molecule: Molecule) -> str:
+        return get_smiles(molecule)
 
     def __str__(self) -> str:
         return repr(self)
