@@ -659,17 +659,34 @@ class Linear(TopologyGraph):
 
         clone: dict[BuildingBlock, abc.Sequence[Vertex]]
         clone = {}
+        terminal_ids = {
+            0,
+            max(
+                vertex.get_id()
+                for vertex_list in building_block_vertices.values()
+                for vertex in vertex_list
+            )
+        }
         for building_block, vertices in (
             building_block_vertices.items()
         ):
-            # Building blocks with 1 placer, cannot be aligned and
-            # must therefore use an UnaligningVertex.
+            # Building blocks with 1 placer, cannot be aligned on
+            # linear vertices and must therefore use an
+            # UnaligningVertex. Building blocks with 1 placer can be
+            # placed on terminal vertices (HeadVertex or TailVertex).
+            # This can be discerned based on the knowledge that the
+            # first and last vertex are the Head and Tail,
+            # respectively.
             if building_block.get_num_placers() == 1:
                 clone[building_block] = tuple(
-                    UnaligningVertex(
-                        id=vertex.get_id(),
-                        position=vertex.get_position(),
-                        flip=vertex.get_flip(),
+                    (
+                        UnaligningVertex(
+                            id=vertex.get_id(),
+                            position=vertex.get_position(),
+                            flip=vertex.get_flip(),
+                        )
+                        if vertex.get_id() not in terminal_ids
+                        else vertex
                     ) for vertex in vertices
                 )
             else:
